@@ -199,7 +199,7 @@ QByteArray Content::assembleHeaders()
     QByteArray newHead;
     for (const Headers::Base *h : std::as_const(d->headers)) {
         if (!h->isEmpty()) {
-            newHead += h->as7BitString() + '\n';
+            newHead += foldHeader(h->as7BitString()) + '\n';
         }
     }
 
